# transitfeed

Provides a library to help you parse, validate, and generate [General Transit Feed Spec (GTFS)](https://developers.google.com/transit/gtfs/) feed files.  See INSTALL for installation instructions.

For the latest documentation, see:

https://github.com/google/transitfeed/wiki

For the latest release and downloads, see:

https://github.com/google/transitfeed/releases/latest

For general questions, send a message to the mailing list:

https://groups.google.com/forum/#!forum/transitfeed
